@@ -24,7 +24,6 @@
 #include <stdio.h>
 #include <getopt.h>
 #include <string.h>
-#include <malloc.h>
 #include <ctype.h>
 #include "error.h"
 #include "ignore.h"
@@ -39,7 +38,7 @@
 #include "guesscomponent.h"
 #include "tracking.h"
 #include "override.h"
-#include "log.h"
+#include "hooks.h"
 
 /* This file includes the code to include binaries, i.e.
    to create the chunk for the Packages.gz-file and
