@@ -50,7 +50,12 @@ void addfield_free(/*@only@*//*@null@*/struct fieldtoadd *);
 /* that is chunk_replacefields(chunk,{fieldname,strlen,data,strlen},fieldname); */
 /*@null@*/char *chunk_replacefield(const char *, const char *, const char *, bool /*maybemissing*/);
 
+/* make sure a given field is first and remove any later occurences */
+/*@null@*/char *chunk_normalize(const char *, const char *, const char *);
+
 /* reformat control data, removing leading spaces and CRs */
-size_t chunk_extract(char * /*buffer*/, const char */*start*/, /*@out@*/char ** /*next*/);
+size_t chunk_extract(char * /*buffer*/, const char */*start*/, size_t, bool, /*@out@*/const char ** /*next*/);
+const char *chunk_getstart(const char *, size_t, bool /*commentsallowed*/);
+const char *chunk_over(const char *);
 
 #endif
