@@ -20,7 +20,6 @@
 #include <errno.h>
 #include <assert.h>
 #include <limits.h>
-#include <malloc.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -1760,12 +1759,12 @@ static int paireddatacompare(UNUSED(DB *db), const DBT *a, const DBT *b) {
 }
 
 retvalue database_opentracking(const char *codename, bool readonly, struct table **table_p) {
-	struct table *table IFSTUPIDCC(=NULL);
+	struct table *table;
 	retvalue r;
 
 	if (rdb_nopackages) {
 		(void)fputs(
-"Internal Error: Accessing packages databse while that was not prepared!\n",
+"Internal Error: Accessing packages database while that was not prepared!\n",
 				stderr);
 		return RET_ERROR;
 	}
@@ -1788,12 +1787,12 @@ retvalue database_opentracking(const char *codename, bool readonly, struct table
 }
 
 retvalue database_openpackages(const char *identifier, bool readonly, struct table **table_p) {
-	struct table *table IFSTUPIDCC(=NULL);
+	struct table *table;
 	retvalue r;
 
 	if (rdb_nopackages) {
 		(void)fputs(
-"Internal Error: Accessing packages databse while that was not prepared!\n",
+"Internal Error: Accessing packages database while that was not prepared!\n",
 				stderr);
 		return RET_ERROR;
 	}
