@@ -22,7 +22,6 @@
 #include <stdarg.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <malloc.h>
 #include <string.h>
 #include <ctype.h>
 #include <time.h>
@@ -236,7 +235,7 @@ CFstartparse(distribution) {
 	return RET_OK;
 }
 
-static bool notpropersuperset(const struct atomlist *allowed, const char *allowedname, const struct atomlist *check, const char *checkname, const char **atoms, const struct configiterator *iter, const struct distribution *d) {
+static bool notpropersuperset(const struct atomlist *allowed, const char *allowedname, const struct atomlist *check, const char *checkname, const char **atoms, const struct distribution *d) {
 	atom_t missing;
 
 	if (!atomlist_subset(allowed, check, &missing)) {
@@ -320,22 +319,18 @@ CFfinishparse(distribution) {
 
 	if (notpropersuperset(&n->architectures, "Architectures",
 			    &n->contents_architectures, "ContentsArchitectures",
-			    atoms_architectures,
-			    iter, n) ||
+			    atoms_architectures, n) ||
 	    notpropersuperset(&n->components, "Components",
 			    &n->contents_components, "ContentsComponents",
-			    atoms_components,
-			    iter, n) ||
+			    atoms_components, n) ||
 	    notpropersuperset(&n->udebcomponents, "UDebComponents",
 			    &n->contents_ucomponents, "ContentsUComponents",
-			    atoms_components,
-			    iter, n) ||
+			    atoms_components, n) ||
 	    // TODO: instead of checking here make sure it can have more
 	    // in the rest of the code...:
 	    notpropersuperset(&n->components, "Components",
 			    &n->udebcomponents, "UDebComponents",
-			    atoms_components,
-			    iter, n)) {
+			    atoms_components, n)) {
 		(void)distribution_free(n);
 		return RET_ERROR;
 	}
@@ -522,7 +517,7 @@ retvalue distribution_readall(struct distribution **distributions) {
 retvalue distribution_foreach_package(struct distribution *distribution, const struct atomlist *components, const struct atomlist *architectures, const struct atomlist *packagetypes, each_package_action action, each_target_action target_action, void *data) {
 	retvalue result, r;
 	struct target *t;
-	struct target_cursor iterator IFSTUPIDCC(=TARGET_CURSOR_ZERO);
+	struct target_cursor iterator;
 	const char *package, *control;
 
 	result = RET_NOTHING;
@@ -558,7 +553,7 @@ retvalue distribution_foreach_package_c(struct distribution *distribution, const
 	retvalue result, r;
 	struct target *t;
 	const char *package, *control;
-	struct target_cursor iterator IFSTUPIDCC(=TARGET_CURSOR_ZERO);
+	struct target_cursor iterator;
 
 	result = RET_NOTHING;
 	for (t = distribution->targets ; t != NULL ; t = t->next) {
@@ -966,58 +961,6 @@ retvalue distribution_exportlist(enum exportwhen when, struct distribution *dist
 	return result;
 }
 
-retvalue distribution_export(enum exportwhen when, struct distribution *distribution) {
-	if (when == EXPORT_SILENT_NEVER) {
-		struct target *t;
-
-		for (t = distribution->targets ; t != NULL ; t = t->next)
-			t->wasmodified = false;
-		return RET_NOTHING;
-	}
-	if (when == EXPORT_NEVER) {
-		if (verbose >= 10)
-			fprintf(stderr,
-"Not exporting %s because of --export=never.\n"
-"Make sure to run a full export soon.\n", distribution->codename);
-		return RET_NOTHING;
-	}
-	if (when != EXPORT_FORCE &&
-			(RET_WAS_ERROR(distribution->status)||interrupted())) {
-		if (verbose >= 10)
-			fprintf(stderr,
-"Not exporting %s because there have been errors and no --export=force.\n"
-"Make sure to run a full export soon.\n", distribution->codename);
-		return RET_NOTHING;
-	}
-	if (when == EXPORT_CHANGED && distribution->status == RET_NOTHING) {
-		struct target *t;
-
-		if (verbose >= 10)
-			fprintf(stderr,
-"Not exporting %s because of no recorded changes and --export=changed.\n",
-	distribution->codename);
-
-		/* some paranoid check */
-
-		for (t = distribution->targets ; t != NULL ; t = t->next) {
-			if (t->wasmodified) {
-				fprintf(stderr,
-"A paranoid check found distribution %s would not have been exported,\n"
-"despite having parts that are marked changed by deeper code.\n"
-"Please report this and how you got this message as bugreport. Thanks.\n"
-"Doing a export despite --export=changed....\n",
-						distribution->codename);
-				return export(distribution, true);
-				break;
-			}
-		}
-
-		return RET_NOTHING;
-	}
-	if (verbose >= 0)
-		printf("Exporting indices...\n");
-	return export(distribution, true);
-}
 
 /* get a pointer to the apropiate part of the linked list */
 struct distribution *distribution_find(struct distribution *distributions, const char *name) {
