@@ -93,7 +93,7 @@ struct distribution {
 	 * files via include */
 	struct strlist alsoaccept;
 	/* if != 0, number of seconds to add for Vaild-Until */
-	time_t validfor;
+	unsigned long validfor;
 	/* RET_NOTHING: do not export with EXPORT_CHANGED, EXPORT_NEVER
 	 * RET_OK: export unless EXPORT_NEVER
 	 * RET_ERROR_*: only export with EXPORT_FORCE */
@@ -130,12 +130,10 @@ retvalue distribution_remove_packages(struct distribution *, const struct atomli
 /* like distribtion_getpart, but returns NULL if there is no such target */
 /*@null@*//*@dependent@*/struct target *distribution_gettarget(const struct distribution *distribution, component_t, architecture_t, packagetype_t);
 
-retvalue distribution_fullexport(struct distribution *distribution);
+retvalue distribution_fullexport(struct distribution *);
 
-enum exportwhen {EXPORT_NEVER, EXPORT_SILENT_NEVER, EXPORT_CHANGED, EXPORT_NORMAL, EXPORT_FORCE };
-retvalue distribution_export(enum exportwhen, struct distribution *);
 
-retvalue distribution_snapshot(struct distribution *distribution, const char *name);
+retvalue distribution_snapshot(struct distribution *, const char */*name*/);
 
 /* read the configuration from all distributions */
 retvalue distribution_readall(/*@out@*/struct distribution **distributions);
@@ -147,7 +145,8 @@ retvalue distribution_match(struct distribution * /*alldistributions*/, int /*ar
 struct distribution *distribution_find(struct distribution *, const char *);
 
 retvalue distribution_freelist(/*@only@*/struct distribution *distributions);
-retvalue distribution_exportlist(enum exportwhen when, /*@only@*/struct distribution *distributions);
+enum exportwhen {EXPORT_NEVER, EXPORT_SILENT_NEVER, EXPORT_CHANGED, EXPORT_NORMAL, EXPORT_FORCE };
+retvalue distribution_exportlist(enum exportwhen when, /*@only@*/struct distribution *);
 
 retvalue distribution_loadalloverrides(struct distribution *);
 void distribution_unloadoverrides(struct distribution *distribution);
