@@ -15,7 +15,6 @@
  */
 #include <config.h>
 
-#include <malloc.h>
 #include <stdlib.h>
 #include <assert.h>
 #include <string.h>
@@ -429,7 +428,7 @@ static retvalue filelist_addfiles(struct filelist_list *list, const struct filel
 }
 
 retvalue filelist_addpackage(struct filelist_list *list, const char *packagename, const char *section, const char *filekey) {
-	const struct filelist_package *package IFSTUPIDCC(=NULL);
+	const struct filelist_package *package;
 	char *debfilename, *contents = NULL;
 	retvalue r;
 	const char *c;
