@@ -22,7 +22,6 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
-#include <malloc.h>
 #include "error.h"
 #include "mprintf.h"
 #include "strlist.h"
@@ -386,7 +385,7 @@ retvalue filterlist_load(struct filterlist *list, struct configiterator *iter) {
 }
 
 static inline bool find(const char *name, /*@null@*/struct filterlistfile *list) {
-	int cmp IFSTUPIDCC(= 0);
+	int cmp;
 	/*@dependent@*/const struct filterlistitem *last = list->last;
 
 	assert (last != NULL);
