@@ -515,7 +515,7 @@ static retvalue read_old_index(const char *fullfilename, /*@out@*/struct old_ind
 	ssize_t bytes_read;
 	retvalue r;
 
-	memset(oldindex, 0, sizeof(struct old_index_file));
+	setzero(struct old_index_file, oldindex);
 
 	if (!isregularfile(fullfilename))
 		return RET_NOTHING;
@@ -577,12 +577,12 @@ static retvalue read_old_index(const char *fullfilename, /*@out@*/struct old_ind
 "rredtool: File '%s' does not look like created by rredtool, ignoring!\n",
 				fullfilename);
 		old_index_done(oldindex);
-		memset(oldindex, 0, sizeof(struct old_index_file));
+		setzero(struct old_index_file, oldindex);
 		return RET_NOTHING;
 	}
 	if (RET_WAS_ERROR(r)) {
 		old_index_done(oldindex);
-		memset(oldindex, 0, sizeof(struct old_index_file));
+		setzero(struct old_index_file, oldindex);
 		return r;
 	}
 	return RET_OK;
@@ -1323,7 +1323,7 @@ int main(int argc, const char *argv[]) {
 	bool patchmode = false;
 	bool repreprohook = false;
 	int i, count;
-	const char *sourcename IFSTUPIDCC(=NULL);
+	const char *sourcename;
 	int debug = 0;
 
 	while ((i = getopt_long(argc, (char**)argv, "+hVDmpR", options, NULL)) != -1) {
@@ -1389,6 +1389,8 @@ int main(int argc, const char *argv[]) {
 			return EXIT_FAILURE;
 		}
 		sourcename = argv[i++];
+	} else {
+		SETBUTNOTUSED( sourcename = NULL; )
 	}
 	if (mergemode && patchmode) {
 		fprintf(stderr,
